@@ -193,10 +193,11 @@ class Property():
     def check(self, value):
         while True:
             answer = input(
-                "\nIs '" + self.value + "' the correct " + self.name +
-                " ? (If correct, press enter. " +
-                "Otherwise, enter the correct value or 'n' for none. " +
-                "To see why this value was determined, enter 'y') "
+                '\nIs "' + self.value + '" the correct ' + self.name +
+                ' ? (If correct, press enter. ' +
+                'Otherwise, enter the correct value or "n" for none. '
+                'To see why this value was determined, enter "y." '
+                'To restart processing this activity, enter "r") '
             )
             if answer == '':
                 return value
